@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Role::RepoFileInjector; # git description: v0.007-10-gd1984bf
+package Dist::Zilla::Role::RepoFileInjector; # git description: v0.008-2-g97bfee5
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Create files outside the build directory
 # KEYWORDS: plugin distribution generate create file repository
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Moose::Role;
 
@@ -45,7 +45,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         version => $VERSION,
         allow_overwrite => ( $self->allow_overwrite ? 1 : 0 ),
-        repo_root => ( $self->_has_repo_root ? $self->repo_root : '.' ),
+        repo_root => ( $self->_has_repo_root ? path($self->repo_root)->stringify : '.' ),
     };
     return $config;
 };
@@ -93,7 +93,7 @@ sub write_repo_files
             if $abs_filename->exists;
 
         $self->log_debug([ 'writing out %s%s', $file->name,
-            $filename->is_relative ? ' to ' . $self->repo_root : '' ]);
+            $filename->is_relative ? ' to ' . path($self->repo_root)->stringify : '' ]);
 
         Carp::croak("attempted to write $filename multiple times") if $abs_filename->exists;
         $abs_filename->touchpath;
@@ -120,7 +120,7 @@ Dist::Zilla::Role::RepoFileInjector - Create files outside the build directory
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
